@@ -5,6 +5,7 @@ use warnings;
 use base 'Catalyst::Controller::SOAP';
 
 __PACKAGE__->config->{wsdl} = 't/hello.wsdl';
+__PACKAGE__->config->{soap_action_prefix} = 'http://example.com/actions/';
 
 sub Greet : Local SOAP('DocumentLiteral') {
     my ( $self, $c, $args ) = @_;
@@ -13,4 +14,6 @@ sub Greet : Local SOAP('DocumentLiteral') {
     $c->stash->{soap}->compile_return({ details => { greeting => $grt.' '.$who.'!' }});
 }
 
+sub doclw : Local ActionClass('SOAP::DocumentLiteralWrapped') { }
+
 1;
